======================
Command Line Interface
======================

This document describes the various command line tools exposed by
``oslo.policy`` to manage policies and policy files.

.. toctree::
   :maxdepth: 1

   oslopolicy-checker
   oslopolicy-validator
   oslopolicy-list-redundant
   oslopolicy-policy-generator
   oslopolicy-sample-generator
   oslopolicy-convert-json-to-yaml
